<?php
namespace FiloBlu\ExtMysqlSearch\Observer;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use FiloBlu\ExtMysqlSearch\Helper\Data;
use Psr\Log\LoggerInterface;
use Magento\Framework\App\Request\Http;
use Magento\Catalog\Model\Config;

class OrderCollectionBeforeLoad implements ObserverInterface
{

    /**
     * @var LoggerInterface
     */
    private $logger;
    /**
     * @var Data
     */
    private $data;
    /**
     * @var Http
     */
    private $requests;
    /**
     * @var Config
     */
    private $config;

    /**
     * OrderCollectionBeforeLoad constructor.
     * @param Data $data
     * @param LoggerInterface $logger
     * @param Http $requests
     * @param Config $config
     */
    public function __construct(
        Data $data,
        LoggerInterface $logger,
        Http $requests,
        Config $config)
    {
        $this->logger = $logger;
        $this->data = $data;
        $this->requests = $requests;
        $this->config = $config;
    }

    /**
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        try{
            if($this->data->isSortOrderByAttributeEnable()){

                /** @var \Magento\Eav\Model\Entity\Collection\AbstractCollection $collection */
                $collection = $observer->getData('collection');

                if(!$collection instanceof \Magento\CatalogSearch\Model\ResourceModel\Fulltext\Collection){
                    return;
                }

                    $collection->addFieldToSelect($this->data->getSearchOrderAttributeLabel());

                    //check if is a fulltext search or category listing
                    $operands = $collection->getQuery()->getFilters()->getOperands();
                    if(isset($operands['search']) && $operands['search']->getText() != ""){
                        $dir = $this->data->getSortDirection();
                        $collection->addAttributeToSort($this->data->getSearchOrderAttribute(),$dir);
                    }else{
                        $code = (int)$this->requests->getParam('product_list_order');
                        if($code){
                          $collection->addAttributeToSort($code);
                        }
                        else{
                            $collection->addAttributeToSort('position',$this->requests->getParam('product_list_dir','ASC'));
                        }
                    }
            }
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
        }catch (\Throwable $t){
            $this->logger->critical($t->getMessage());
        }


    }





}